==> 4.5.0.tar.gz: terraform-provider-decort/internal/service/cloudbroker/kvmvm/resource_check_input_values.go <==
package kvmvm

import (
	"context"

	"github.com/hashicorp/terraform-plugin-sdk/v2/diag"
	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/dc"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/ic"
)

func checkParamsExistence(ctx context.Context, d *schema.ResourceData, c *controller.ControllerCfg) diag.Diagnostics {
	errs := []error{}

	if err := ic.ExistRG(ctx, uint64(d.Get("rg_id").(int)), c); err != nil {
		errs = append(errs, err)
	}

	if err := ic.ExistImage(ctx, uint64(d.Get("image_id").(int)), c); err != nil {
		errs = append(errs, err)
	}

	if netErrs := existNetworks(ctx, d, c); errs != nil {
		errs = append(errs, netErrs...)
	}

	return dc.ErrorsToDiagnostics(errs)
}

func existNetworks(ctx context.Context, d *schema.ResourceData, c *controller.ControllerCfg) []error {
	var errs []error
	var vinsIds, extNetIds []uint64

	networksIface, ok := d.GetOk("network")
	if !ok {
		return nil
	}

	networkList := networksIface.(*schema.Set).List()
	for _, elem := range networkList {
		network := elem.(map[string]interface{})

		switch network["net_type"].(string) {
		case "VINS":
			vinsIds = append(vinsIds, uint64(network["net_id"].(int)))
		case "EXTNET":
			extNetIds = append(extNetIds, uint64(network["net_id"].(int)))
		default:
			continue
		}
	}

	if vinsErrs := ic.ExistVinses(ctx, vinsIds, c); vinsErrs != nil {
		errs = append(errs, vinsErrs...)
	}

	if extNetErrs := ic.ExistExtNets(ctx, extNetIds, c); extNetErrs != nil {
		errs = append(errs, extNetErrs...)
	}

	return errs
}

==> 4.7.4.tar.gz: terraform-provider-decort/internal/service/cloudbroker/kvmvm/resource_check_input_values.go <==
package kvmvm

import (
	"context"

	"github.com/hashicorp/terraform-plugin-sdk/v2/diag"
	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/dc"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/ic"
)

func checkParamsExistence(ctx context.Context, d *schema.ResourceData, c *controller.ControllerCfg) diag.Diagnostics {
	errs := []error{}

	if err := ic.ExistRG(ctx, uint64(d.Get("rg_id").(int)), c); err != nil {
		errs = append(errs, err)
	}

	if err := ic.ExistImage(ctx, uint64(d.Get("image_id").(int)), c); err != nil {
		errs = append(errs, err)
	}

	if netErrs := existNetworks(ctx, d, c); errs != nil {
		errs = append(errs, netErrs...)
	}

	if disks, ok := d.GetOk("disks"); ok {
		if err := ic.IsMoreThanOneDisksTypeB(ctx, disks); err != nil {
			errs = append(errs, err)
		}
	}

	return dc.ErrorsToDiagnostics(errs)
}

func existNetworks(ctx context.Context, d *schema.ResourceData, c *controller.ControllerCfg) []error {
	var errs []error
	var vinsIds, extNetIds, vfpoolIds, dpdkIds []uint64

	networksIface, ok := d.GetOk("network")
	if !ok {
		return nil
	}

	networkList := networksIface.(*schema.Set).List()
	for _, elem := range networkList {
		network := elem.(map[string]interface{})

		switch network["net_type"].(string) {
		case "VINS":
			vinsIds = append(vinsIds, uint64(network["net_id"].(int)))
		case "EXTNET":
			extNetIds = append(extNetIds, uint64(network["net_id"].(int)))
		case "VFNIC":
			vfpoolIds = append(vfpoolIds, uint64(network["net_id"].(int)))
		case "DPDK":
			dpdkIds = append(dpdkIds, uint64(network["net_id"].(int)))
		default:
			continue
		}
	}

	if vinsErrs := ic.ExistVinses(ctx, vinsIds, c); vinsErrs != nil {
		errs = append(errs, vinsErrs...)
	}

	if extNetErrs := ic.ExistExtNets(ctx, extNetIds, c); extNetErrs != nil {
		errs = append(errs, extNetErrs...)
	}

	if vfpoolErrs := ic.ExistVFPools(ctx, vfpoolIds, c); vfpoolErrs != nil {
		errs = append(errs, vfpoolErrs...)
	}

	if dpdkErrs := ic.ExistDPDKNet(ctx, dpdkIds, c); dpdkErrs != nil {
		errs = append(errs, dpdkErrs...)
	}

	return errs
}
